@@ -103,10 +103,6 @@ pub(crate) const ERR_PREFIX: &str = "org.bluez.Error.";
 #[cfg(feature = "bluetoothd")]
 pub(crate) const TIMEOUT: Duration = Duration::from_secs(120);
 
-// Redefine here to avoid dependency on libbluetooth for AddressType.
-pub(crate) const BDADDR_LE_PUBLIC: i32 = 0x01;
-pub(crate) const BDADDR_LE_RANDOM: i32 = 0x02;
-
 #[cfg(feature = "bluetoothd")]
 macro_rules! publish_path {
     ($path:expr) => {
@@ -222,6 +218,7 @@ macro_rules! define_properties {
         $(#[$outer])*
         pub async fn $getter_name(&self) -> crate::Result<Option<$type>> {
             let dbus_opt_value: Option<$dbus_type> = self.get_opt_property_with_interface($dbus_name, $dbus_interface).await?;
+            #[allow(clippy::manual_map)]
             let value: Option<$type> = match dbus_opt_value.as_ref() {
                 Some($dbus_value) => Some($getter_transform),
                 None => None
@@ -367,7 +364,7 @@ macro_rules! define_flags {
 
         impl $name {
             #[allow(dead_code)]
-            pub(crate) fn to_vec(&self) -> Vec<String> {
+            pub(crate) fn as_vec(&self) -> Vec<String> {
                 let mut v = Vec::new();
                 $(
                     if self.$field {
@@ -424,6 +421,7 @@ pub mod gatt;
 pub mod l2cap;
 #[cfg(feature = "bluetoothd")]
 mod session;
+mod sys;
 
 #[cfg(feature = "bluetoothd")]
 pub use crate::{adapter::*, device::*, session::*};
@@ -631,20 +629,6 @@ impl Address {
     pub const fn any() -> Self {
         Self([0; 6])
     }
-
-    /// Address as system socket address type.
-    #[cfg(feature = "l2cap")]
-    pub fn to_bdaddr(mut self) -> libbluetooth::bluetooth::bdaddr_t {
-        self.0.reverse();
-        libbluetooth::bluetooth::bdaddr_t { b: self.0 }
-    }
-
-    /// Address from system socket address type.
-    #[cfg(feature = "l2cap")]
-    pub fn from_bdaddr(mut addr: libbluetooth::bluetooth::bdaddr_t) -> Self {
-        addr.b.reverse();
-        Self(addr.b)
-    }
 }
 
 impl Deref for Address {
@@ -677,6 +661,20 @@ impl Debug for Address {
     }
 }
 
+impl From<sys::bdaddr_t> for Address {
+    fn from(mut addr: sys::bdaddr_t) -> Self {
+        addr.b.reverse();
+        Self(addr.b)
+    }
+}
+
+impl From<Address> for sys::bdaddr_t {
+    fn from(mut addr: Address) -> Self {
+        addr.0.reverse();
+        sys::bdaddr_t { b: addr.0 }
+    }
+}
+
 /// Invalid Bluetooth address error.
 #[derive(Debug, Clone)]
 pub struct InvalidAddress(pub String);
@@ -714,13 +712,14 @@ impl From<Address> for [u8; 6] {
 
 /// Bluetooth device address type.
 #[derive(Clone, Copy, Debug, Eq, PartialEq, Ord, PartialOrd, Hash, Display, EnumString, FromPrimitive)]
+#[repr(u8)]
 pub enum AddressType {
     /// Public address.
     #[strum(serialize = "public")]
-    Public = BDADDR_LE_PUBLIC as _,
+    Public = sys::BDADDR_LE_PUBLIC,
     /// Random address.
     #[strum(serialize = "random")]
-    Random = BDADDR_LE_RANDOM as _,
+    Random = sys::BDADDR_LE_RANDOM,
 }
 
 impl Default for AddressType {
@@ -783,7 +782,8 @@ async fn all_dbus_objects(
 pub(crate) fn read_dict<'a, T: 'static>(
     dict: &'a HashMap<String, Variant<Box<dyn RefArg + 'static>>>, key: &str,
 ) -> Result<&'a T> {
-    prop_cast(dict, key).ok_or(Error::new(ErrorKind::Internal(InternalErrorKind::MissingKey(key.to_string()))))
+    prop_cast(dict, key)
+        .ok_or_else(|| Error::new(ErrorKind::Internal(InternalErrorKind::MissingKey(key.to_string()))))
 }
 
 /// Returns the parent path of the specified D-Bus path.
